import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/localization.dart';
import 'package:lottie/lottie.dart';

import '../utils/colors.dart';
import '../utils/commonComponents.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/utility_class.dart';

// ignore: must_be_immutable
class appChatFooter extends StatefulWidget {
  String? hintText;
  Function(String?) onValueRecieved;
  Function(String, String?)? onReceiveOption;
  Function(String)? onTyping;
  bool? isShowAddIcon = false;

  String? userName;
  Function()? onCrossCLicked;
  bool? isEmptyTextAccepted;
  String? linkPreviewUrl;

  Function(bool)? audioEvent;
  String? message;

  appChatFooter(
    Key key, {
    this.hintText,
    required this.onValueRecieved,
    this.onTyping,
    this.message,
    this.userName,
    this.audioEvent,
    this.linkPreviewUrl,
    this.isEmptyTextAccepted,
    this.isShowAddIcon,
    this.onCrossCLicked,
    this.onReceiveOption,
  }) : super(key: key);

  appChatFooterState createState() => appChatFooterState(
        onValueRecieved: onValueRecieved,
        linkPreviewUrl: linkPreviewUrl,
        onTyping: onTyping,
        isEmptyTextAccepted: isEmptyTextAccepted,
        onCrossCLicked: onCrossCLicked,
        isShowAddIcon: isShowAddIcon,
        onReceiveOption: onReceiveOption,
        userName: userName,
      );
}

class appChatFooterState extends State<appChatFooter> {
  bool isTyping = false;
  bool isRecordingAudio = false;
  bool? isEmptyTextAccepted;
  Function(String, String?)? onReceiveOption;
  String? hintText;
  String? value;
  String? linkPreviewUrl;

  final GlobalKey<PopupMenuButtonState<int>> _key = GlobalKey();

  bool? isShowAddIcon = false;
  Function(String?) onValueRecieved;
  Function()? onCrossCLicked;
  Function(String)? onTyping;
  TextStyleElements? styleElements;
  bool isNameEntered = false;
  bool isPhoneEntered = false;
  bool isEmailEntered = false;
  bool isBusinessEntered = false;
  var controller = TextEditingController();
  String? userName;

  appChatFooterState({
    this.hintText,
    required this.onValueRecieved,
    this.onTyping,
    this.isEmptyTextAccepted,
    this.isShowAddIcon,
    this.onCrossCLicked,
    this.linkPreviewUrl,
    this.onReceiveOption,
    this.userName,
  });

  @override
  void initState() {
    WidgetsBinding.instance!.addPostFrameCallback((_) {
      if (widget.message != null) controller.text = widget.message ?? "";
    });

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return Container(
      color: HexColor(AppColors.appColorBackground),
      child: Container(
          padding: const EdgeInsets.only(top: 16),
          color: HexColor(AppColors.appColorWhite),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Visibility(
                visible: false,
                child: Padding(
                  padding: const EdgeInsets.only(left: 8.0, right: 8.0),
                  child: Card(
                      margin: EdgeInsets.zero,
                      child: Padding(
                        padding: const EdgeInsets.only(
                            left: 4.0, right: 4.0, top: 4.0),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: [
                            Padding(
                              padding: EdgeInsets.only(
                                left: 8.0,
                              ),
                              child: Row(
                                crossAxisAlignment: CrossAxisAlignment.center,
                                mainAxisAlignment:
                                    MainAxisAlignment.spaceBetween,
                                children: [
                                  Text(userName ?? "",
                                      maxLines: 1,
                                      overflow: TextOverflow.ellipsis,
                                      style: styleElements!
                                          .bodyText2ThemeScalable(context)
                                          .copyWith(
                                              color: HexColor(
                                                  AppColors.orangeText))),
                                  InkWell(
                                    onTap: () {
                                      if (onCrossCLicked != null)
                                        onCrossCLicked!();
                                    },
                                    child: Padding(
                                      padding:
                                          const EdgeInsets.only(right: 4.0),
                                      child: Icon(
                                        Icons.cancel_outlined,
                                        color:
                                            HexColor(AppColors.appColorBlack35),
                                        size: 16,
                                      ),
                                    ),
                                  ),
                                ],
                              ),
                            ),
                            GestureDetector(
                                onTap: () {},
                                child: Padding(
                                    padding: EdgeInsets.only(
                                        left: 8.0,
                                        right: 16.0,
                                        top: 2.0,
                                        bottom: 8.0),
                                    child: Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.start,
                                      children: [
                                        Visibility(
                                          visible: true,
                                          child: Container(
                                            margin: const EdgeInsets.only(
                                                right: 12),
                                            width: 68,
                                            height: 68,
                                            decoration: BoxDecoration(
                                                borderRadius:
                                                    BorderRadius.circular(8),
                                                image: DecorationImage(
                                                    fit: BoxFit.cover,
                                                    image:
                                                        CachedNetworkImageProvider(
                                                      "",
                                                    ))),
                                          ),
                                        ),
                                        Flexible(
                                            child: Container(
                                                margin: const EdgeInsets.only(
                                                    right: 12),
                                                child: Align(
                                                    alignment:
                                                        Alignment.topLeft,
                                                    child: Text("",
                                                        maxLines: 3,
                                                        overflow: TextOverflow
                                                            .ellipsis,
                                                        style: styleElements!
                                                            .bodyText1ThemeScalable(
                                                                context))))),
                                      ],
                                    )))
                          ],
                        ),
                      )),
                ),
              ),
              Container(
                child: Center(
                  child: Padding(
                    padding: EdgeInsets.only(bottom: 16, left: 16, right: 16),
                    child: Text(
                      !isNameEntered
                          ? "Name"
                          : !isPhoneEntered
                              ? "Phone"
                              : !isEmailEntered
                                  ? "Email"
                                  : !isBusinessEntered
                                      ? "Business Name"
                                      : "Name",
                      textAlign: TextAlign.center,
                      style: styleElements!
                          .subtitle1ThemeScalable(context)
                          .copyWith(color: HexColor(AppColors.appColorBlack85)),
                    ),
                  ),
                ),
              ),
              Container(
                child: Center(
                  child: Padding(
                    padding: EdgeInsets.only(bottom: 24, left: 16, right: 16),
                    child: Text(
                      !isNameEntered
                          ? "Enter the name of the contact person of the lead"
                          : !isPhoneEntered
                              ? "Enter the phone of the contact person"
                              : !isEmailEntered
                                  ? "Enter the email of the contact person"
                                  : !isBusinessEntered
                                      ? "Enter the business name of the lead"
                                      : "Optionally you can select products that the lead is interested in",
                      textAlign: TextAlign.center,
                      style: styleElements!
                          .captionThemeScalable(context)
                          .copyWith(color: HexColor(AppColors.appColorBlack35)),
                    ),
                  ),
                ),
              ),
              Padding(
                padding: EdgeInsets.only(bottom: 0, left: 18, right: 16),
                child: Text(

                  !isNameEntered
                      ?  "Contact person name"
                      : !isPhoneEntered
                      ? "Phone Number"
                      : !isEmailEntered
                      ? "Email ID"
                      : !isBusinessEntered
                      ? "Business Name"
                      : "Products",




                  style: styleElements!
                      .captionThemeScalable(context)
                      .copyWith(color: HexColor(AppColors.appColorBlack35)),
                ),
              ),
              Padding(
                padding: EdgeInsets.only(bottom: 8, left: 16, right: 16),
                child: Row(
                  children: [
                    Expanded(
                      child: Container(
                        decoration: BoxDecoration(
                            color: HexColor(AppColors.appColorWhite),
                            shape: BoxShape.rectangle,
                            borderRadius: BorderRadius.circular(25),
                            boxShadow: [CommonComponents().getShadowforBox()]),
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            !isRecordingAudio
                                ? Expanded(
                                    child: TextField(
                                      maxLines: 10,
                                      minLines: 1,
                                      textInputAction: TextInputAction.next,
                                      textCapitalization:
                                          TextCapitalization.sentences,
                                      style: styleElements!
                                          .subtitle1ThemeScalable(context)
                                          .copyWith(
                                              color: HexColor(
                                                  AppColors.appColorBlack65)),
                                      decoration: InputDecoration(
                                          contentPadding:
                                              EdgeInsets.only(left: 24),
                                          hintText:    !isNameEntered
                                              ?  "Mr."
                                              : !isPhoneEntered
                                               ? "+91"
                                              : !isEmailEntered
                                              ? ""
                                              : !isBusinessEntered
                                              ? ""
                                              : "Click to select products",
                                          border: InputBorder.none,
                                          focusedBorder: InputBorder.none,
                                          enabledBorder: InputBorder.none,
                                          errorBorder: InputBorder.none,
                                          disabledBorder: InputBorder.none,
                                          hintStyle: styleElements!
                                              .bodyText2ThemeScalable(context)
                                              .copyWith(
                                                  color: HexColor(AppColors
                                                      .blueApp))),
                                      controller: controller,
                                      onChanged: (value) {
                                        this.value = value;
                                        if (value.isNotEmpty) {
                                          setState(() {
                                            isTyping = true;
                                          });
                                        } else {
                                          setState(() {
                                            isTyping = false;
                                          });
                                        }

                                        if (onTyping != null) onTyping!(value);
                                      },
                                    ),
                                  )
                                : Expanded(
                                    child: Container(
                                      child: Center(
                                        child: SizedBox(
                                          width: 60,
                                          child: Lottie.asset(
                                            'assets/jsonfiles/lottie_voice.json',
                                            width: 60,
                                            height: 60,
                                            fit: BoxFit.fill,
                                          ),
                                        ),
                                      ),
                                    ),
                                  ),
                            Visibility(
                                visible: isShowAddIcon!,
                                child: popItem(
                                  Padding(
                                    padding: const EdgeInsets.all(8.0),
                                    child: Icon(
                                      Icons.add_circle,
                                      size: 30,
                                      color: HexColor(AppColors.blueApp),
                                    ),
                                  ),
                                )),
                          ],
                        ),
                      ),
                    ),
                    controller.text.isNotEmpty || widget.audioEvent == null
                        ? getContainer(Center(
                            child: IconButton(
                            splashRadius: 45,
                            icon: Icon(
                              Icons.send_outlined,
                              color: HexColor(AppColors.appColorBlack85),
                            ),
                            onPressed: () {
                              if (isEmptyTextAccepted != null &&
                                  isEmptyTextAccepted!) {

                                onValueRecieved(value);
                                value = null;
                                controller.clear();
                              } else if (value != null && value!.isNotEmpty) {

                                setState(() {
                                  if(!isNameEntered)
                                    {isNameEntered=true;}
                                 else if(!isPhoneEntered)
                                  {isPhoneEntered=true;}
                                 else if(!isEmailEntered)
                                  {isEmailEntered=true;}
                                else
                                  {isBusinessEntered=true;}
                                });

                                onValueRecieved(value);
                                value = null;
                                controller.clear();
                              }
                            },
                          )))
                        : GestureDetector(
                            child: isRecordingAudio
                                ? Lottie.asset(
                                    'assets/jsonfiles/mic_lottie.json',
                                    width: 100,
                                    height: 100,
                                    fit: BoxFit.fill,
                                  )
                                : getContainer(Center(
                                    child: Padding(
                                      padding: const EdgeInsets.all(16.0),
                                      child: Icon(
                                        Icons.mic,
                                        color: Colors.black87,
                                      ),
                                    ),
                                  )),
                            onLongPressStart: (_) async {
                              print("start--------");
                              widget.audioEvent!(true);
                              setState(() {
                                isRecordingAudio = true;
                              });
                            },
                            onLongPressEnd: (_) {
                              print("end--------");
                              widget.audioEvent!(false);
                              setState(() {
                                isRecordingAudio = false;
                              });
                            },
                          )
                  ],
                ),
              ),
            ],
          )),
    );
  }

  Widget popItem(Widget item) {
    return PopupMenuButton<String>(
        offset: const Offset(0, -180),
        key: _key,
        onSelected: (String value) {
          onReceiveOption!(value, controller.text.toString());

          controller.clear();
        },
        child: item,
        itemBuilder: (context) => [
              PopupMenuItem(
                  value: "Image",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.camera_alt_outlined),
                      ),
                      Text(LeadsLocalizations.of(context)!.translate("image"))
                    ],
                  )),
              PopupMenuItem(
                  value: "Video",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.video_call_outlined),
                      ),
                      Text(LeadsLocalizations.of(context)!.translate("video"))
                    ],
                  )),
              PopupMenuItem(
                  value: "File",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.insert_drive_file_outlined),
                      ),
                      Text(LeadsLocalizations.of(context)!.translate("file"))
                    ],
                  )),
              /*   PopupMenuItem(
                  value: "Location",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.location_on_outlined),
                      ),
                      Text(LeadsLocalizations.of(context).translate("location"))
                    ],
                  )),*/
            ]);
  }

  clearData() {
    setState(() {
      controller.clear();
      isTyping = false;
      value = '';
    });
  }

  Widget getContainer(Widget child) {
    return Container(
      decoration: BoxDecoration(
        color: HexColor(AppColors.appColorWhite),
        shape: BoxShape.circle,
        boxShadow: [CommonComponents().getShadowforBox()],
      ),
      margin: EdgeInsets.all(4),
      padding: EdgeInsets.all(0),
      child: Card(
        elevation: 0,
        clipBehavior: Clip.antiAlias,
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(25)),
        child: child,
      ),
    );
  }
}
