import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../enums/ticket_list_type.dart';
import '../utils/appAvatar.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/localization.dart';
import '../utils/searchBox.dart';
import '../utils/text_styling.dart';


// ignore: must_be_immutable
class HelpDeskAppBar extends StatelessWidget with PreferredSizeWidget {
  final double appBarHeight = 150.0;
  String? imageUrl;
  String? priorityColor;
  String? title;
  String? userType;
  int? userId;
  String? ticketStatus;
  String? priority;
  int? ticketId;
  String? status;
  String? issueType;
  String? dueDays;
  bool? isGroupConversation;
  int? notificationCount;
  Null Function()? callBack;
  Null Function()? onMoreClick;
  Null Function() agentListCallback;
  Null Function(String value)? onSearch;
  Null Function(String value)? onItemSelect;
  Function? onCallCallback;
  Function? onVideoCallback;
  bool? isHomepage;
  Function? backButtonPress;
  bool? isNotificationVisible;
  bool? isSearch = false;
  int? roomId;
  String? roomName;
  bool? showCallbuttons;
  Null Function()? escalateCallBack;
  Null Function()? statusCallBack;
  Null Function()? priorityCallBack;
  String? agentName;
  String? agentAvatar;
  int? agentId;
  String? bgColor;
  String? currentStatusName;
  bool isPicked;

  @override
  get preferredSize => Size.fromHeight(appBarHeight);
  late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          AppBar(
            automaticallyImplyLeading: false,
            elevation: 0,
            iconTheme: IconThemeData(
              color:
                  HexColor(AppColors.primaryTextColor), //change your color here
            ),
            flexibleSpace: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    InkWell(
                      onTap: backButtonPress as void Function()?,
                      child: Row(
                        mainAxisSize: MainAxisSize.min,
                        mainAxisAlignment: MainAxisAlignment.start,
                        children: [
                          Padding(
                              padding: const EdgeInsets.only(left: 16.0),
                              child: InkWell(
                                onTap: callBack,
                                child: Icon(
                                  Icons.keyboard_backspace_rounded,
                                  size: 20.0.h,
                                  // add custom icons also
                                ),
                              )),
                          Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: appAvatar(
                              key: UniqueKey(),
                              imageUrl: imageUrl!,
                              size: 36,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Expanded(
                      child: isSearch!
                          ? SearchBox(
                              onvalueChanged: (String value) {
                                onSearch!(value);
                              },
                              hintText: "Search",
                            )
                          : GestureDetector(
                              behavior: HitTestBehavior.translucent,
                              onTap: () {
                                // Navigator.push(
                                //     context,
                                //     MaterialPageRoute(
                                //         builder: (context) => UserProfileCards(
                                //               userType: userType == "business"
                                //                   ? "business"
                                //                   : "thirdPerson",
                                //               userId: userId,
                                //               callback: () {
                                //                 callBack!();
                                //               },
                                //               currentPosition: 1,
                                //               type: null,
                                //             )));
                              },
                              child: Column(
                                mainAxisAlignment: MainAxisAlignment.start,
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text(
                                    title ?? "",
                                    style: title != null
                                        ? styleElements
                                            .subtitle1ThemeScalable(context)
                                            .copyWith(
                                                fontWeight: FontWeight.w600)
                                        : styleElements
                                            .headline5ThemeScalable(context),
                                  ),
                                  Text(status ?? "",
                                      style: styleElements
                                          .captionThemeScalable(context)),
                                ],
                              ),
                            ),
                    ),
                    Visibility(
                      // visible: showCallbuttons!,
                      visible: false,
                      child: Container(
                        child: Stack(
                          children: <Widget>[
                            new IconButton(
                              icon: Icon(
                                Icons.call_outlined,
                                size: 24.0,
                                color: HexColor(AppColors.appColorBlack65),
                              ),
                              onPressed: onCallCallback as void Function()?,
                            ),
                          ],
                        ),
                      ),
                    ),
                    Visibility(
                      // visible: showCallbuttons!,
                      visible: false,
                      child: Container(
                        child: Stack(
                          children: <Widget>[
                            new IconButton(
                              icon: Icon(
                                Icons.videocam_outlined,
                                size: 24.0,
                                color: HexColor(AppColors.appColorBlack65),
                              ),
                              onPressed: onVideoCallback as void Function()?,
                            ),
                          ],
                        ),
                      ),
                    ),
                    Visibility(
                        visible: true,
                        child: IconButton(
                          padding: EdgeInsets.only(right: 16),
                          onPressed: onMoreClick,
                          icon: Icon(Icons.more_vert),
                        )),
                    Visibility(
                        visible: false,
                        child: popItem(Padding(
                          padding: const EdgeInsets.only(right: 8.0),
                          child: Icon(
                            Icons.more_vert,
                            size: 24.0,
                            color: HexColor(AppColors.appColorBlack65),
                          ),
                        ))),
                  ],
                ),
                Padding(
                  padding: const EdgeInsets.only(left: 90.0),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      SingleChildScrollView(
                        scrollDirection: Axis.horizontal,
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: [
                            InkWell(
                              onTap: () {},
                              child: Text(
                                ticketId.toString(),
                                textAlign: TextAlign.center,
                                style: styleElements
                                    .bodyText1ThemeScalable(context)
                                    .copyWith(
                                        fontWeight: FontWeight.w500,
                                        color: HexColor(
                                            AppColors.appColorBlack85)),
                              ),
                            ),
                            Padding(
                              padding:
                                  const EdgeInsets.only(left: 8.0, right: 8.0),
                              child: SizedBox(
                                height: 25,
                                child: VerticalDivider(
                                  color: HexColor(AppColors.appColorBlack35),
                                  thickness: 2,
                                  indent: 5,
                                  endIndent: 0,
                                  width: 2,
                                ),
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.only(right: 8.0),
                              child: InkWell(
                                onTap: () {},
                                child: Text(
                                  dueDays ?? "",
                                  style: styleElements
                                      .bodyText2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.w500,
                                          color: HexColor(
                                              AppColors.appColorBlack65)),
                                ),
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.only(right: 8.0),
                              child: SizedBox(
                                height: 25,
                                child: VerticalDivider(
                                  color: HexColor(AppColors.appColorBlack35),
                                  thickness: 2,
                                  indent: 5,
                                  endIndent: 0,
                                  width: 2,
                                ),
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.only(right: 8.0),
                              child: InkWell(
                                onTap: () {},
                                child: Text(
                                  issueType ?? '',
                                  style: styleElements
                                      .bodyText2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.w500,
                                          color: HexColor(
                                              AppColors.appColorBlack65)),
                                ),
                              ),
                            )
                          ],
                        ),
                      ),
                      SingleChildScrollView(
                        scrollDirection: Axis.horizontal,
                        child: Padding(
                          padding: const EdgeInsets.only(top: 4.0),
                          child: Row(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              InkWell(
                                onTap: () {
                                  if (isPicked &&
                                      currentStatusName !=
                                          TicketListStatus.RESOLVED.type &&
                                      currentStatusName !=
                                          TicketListStatus.CLOSED.type) {
                                    priorityCallBack!();
                                  }
                                },
                                child: Card(
                                    color: HexColor(AppColors.appColorWhite),
                                    shape: StadiumBorder(
                                      side: BorderSide(
                                        color:
                                            HexColor(AppColors.appColorWhite),
                                        width: 2.0,
                                      ),
                                    ),
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                          left: 16.0,
                                          right: 16,
                                          top: 8,
                                          bottom: 8),
                                      child: Row(
                                        crossAxisAlignment:
                                            CrossAxisAlignment.center,
                                        children: [
                                          Visibility(
                                            visible: priorityColor != null,
                                            child: Icon(
                                              Icons.circle,
                                              color: HexColor(
                                                  priorityColor ?? "#ffffff"),
                                              size: 15,
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.only(
                                                left: 8.0),
                                            child: Text(
                                              priority ?? '',
                                              style: styleElements
                                                  .captionThemeScalable(context)
                                                  .copyWith(
                                                      fontWeight:
                                                          FontWeight.w500,
                                                      color: HexColor(AppColors
                                                          .appColorBlack85)),
                                            ),
                                          ),
                                        ],
                                      ),
                                    )),
                              ),
                              InkWell(
                                onTap: () {
                                  if (isPicked ||
                                      currentStatusName !=
                                              TicketListStatus.RESOLVED.type &&
                                          currentStatusName !=
                                              TicketListStatus.CLOSED.type) {
                                    statusCallBack!();
                                  }
                                },
                                child: Card(
                                    color: _getColor(ticketStatus ?? ''),
                                    shape: StadiumBorder(
                                      side: BorderSide(
                                        color: _getColor(ticketStatus ?? ''),
                                        width: 2.0,
                                      ),
                                    ),
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                          left: 16.0,
                                          right: 16,
                                          top: 8,
                                          bottom: 8),
                                      child: Text(
                                        ticketStatus ?? '',
                                        style: styleElements
                                            .captionThemeScalable(context)
                                            .copyWith(
                                                fontWeight: FontWeight.w500,
                                                color: HexColor(
                                                    AppColors.appColorBlack85)),
                                      ),
                                    )),
                              ),
                              InkWell(
                                onTap: () {
                                  agentListCallback();
                                  // if (agentId != null && agentId != 0) {
                                  //   Navigator.push(
                                  //       context,
                                  //       MaterialPageRoute(
                                  //           builder: (context) =>
                                  //               UserProfileCards(
                                  //                 userType: "thirdPerson",
                                  //                 userId: agentId,
                                  //                 callback: () {
                                  //                   callBack!();
                                  //                 },
                                  //                 currentPosition: 1,
                                  //                 type: null,
                                  //               )));
                                  // }
                                },
                                child: Card(
                                    color: HexColor(AppColors.appColorWhite),
                                    shape: StadiumBorder(
                                      side: BorderSide(
                                        color:
                                            HexColor(AppColors.appColorWhite),
                                        width: 2.0,
                                      ),
                                    ),
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                          left: 16.0,
                                          right: 16,
                                          top: 8,
                                          bottom: 8),
                                      child: Row(
                                        crossAxisAlignment:
                                            CrossAxisAlignment.start,
                                        children: [
                                          appAvatar(
                                            key: UniqueKey(),
                                            imageUrl: agentAvatar,
                                            size: 18,
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.only(
                                                left: 8.0),
                                            child: Text(
                                              agentName ?? "-",
                                              style: styleElements
                                                  .captionThemeScalable(context)
                                                  .copyWith(
                                                      fontWeight:
                                                          FontWeight.w500,
                                                      color: HexColor(AppColors
                                                          .appColorBlack85)),
                                            ),
                                          ),
                                        ],
                                      ),
                                    )),
                              )
                            ],
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
      decoration: BoxDecoration(
        boxShadow: <BoxShadow>[
          BoxShadow(
              color: bgColor != null
                  ? HexColor(bgColor!)
                  : HexColor(AppColors.appColorWhite),
              blurRadius: 15.0,
              offset: Offset(0.0, 0.75))
        ],
        color: bgColor != null
            ? HexColor(bgColor!)
            : HexColor(AppColors.appColorWhite),
      ),
    );
  }

  Color _getColor(String currentStatusName) {
    if (currentStatusName == TicketListStatus.UNASSIGNED.type) {
      return HexColor(AppColors.UnassignedColor);
    } else if (currentStatusName == TicketListStatus.ASSIGNED.type) {
      return HexColor(AppColors.AssignedColor);
    } else if (currentStatusName == TicketListStatus.ONHOLD.type) {
      return HexColor(AppColors.OnHoldColor);
    } else if (currentStatusName == TicketListStatus.RESOLVED.type) {
      return HexColor(AppColors.ResolvedColor);
    } else if (currentStatusName == TicketListStatus.CLOSED.type) {
      return HexColor(AppColors.ClosedColor);
    } else if (currentStatusName == TicketListStatus.REOPEN.type) {
      return HexColor(AppColors.ReopenColor);
    } else {
      return HexColor(AppColors.UnassignedColor);
    }
  }

  Widget popItem(Widget item) {
    return !isGroupConversation!
        ? PopupMenuButton<String>(
            onSelected: (String value) {
              onItemSelect!(value);
            },
            child: item,
            itemBuilder: (context) => [
                  PopupMenuItem(
                      value: "Search Chat",
                      child: Row(
                        children: <Widget>[
                          Text(LeadsLocalizations.of(context)!
                              .translate("search_chat"))
                        ],
                      )),
                  PopupMenuItem(
                      value: "Block",
                      child: Row(
                        children: <Widget>[
                          Text(LeadsLocalizations.of(context)!.translate("block"))
                        ],
                      ))
                ])
        : PopupMenuButton<String>(
            onSelected: (String value) {
              onItemSelect!(value);
            },
            child: item,
            itemBuilder: (context) => [
                  PopupMenuItem(
                      value: "Search Chat",
                      child: Row(
                        children: <Widget>[
                          Text(LeadsLocalizations.of(context)!
                              .translate("search_chat"))
                        ],
                      )),
                ]);
  }

  HelpDeskAppBar(
      {Key? key,
      this.agentName,
      this.agentAvatar,
      this.agentId,
      this.ticketId,
      this.ticketStatus,
      this.priority,
      this.status,
      this.issueType,
      this.dueDays,
      this.escalateCallBack,
      this.statusCallBack,
      this.priorityCallBack,
      this.imageUrl,
      this.title,
      this.notificationCount,
      this.callBack,
      this.isHomepage,
      this.backButtonPress,
      this.isNotificationVisible,
      this.userId,
      this.userType,
      this.onSearch,
      this.onItemSelect,
      this.isSearch,
      this.roomId,
      this.roomName,
      this.onCallCallback,
      this.onVideoCallback,
      this.showCallbuttons,
      this.onMoreClick,
      this.priorityColor,
      this.bgColor,
      this.currentStatusName,
      required this.agentListCallback,
      required this.isPicked,
      this.isGroupConversation})
      : super(key: key);
}
