import 'package:flutter/material.dart';

import '../../enums/ticket_list_type.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/text_styling.dart';


class FilterTicketSheet extends StatefulWidget {
  final Function(String?, String) callback;
  final String listType;
  final String? status;
  FilterTicketSheet(
      {required this.callback, required this.listType, this.status});
  @override
  FilterTicketSheetState createState() =>
      FilterTicketSheetState(listType: listType, status: status);
}

class FilterTicketSheetState extends State<FilterTicketSheet> {
  TextStyleElements? styleElements;
  String listType;
  String? status;

  FilterTicketSheetState({required this.listType, this.status});

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return CommonHelpdeskSheet(
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: Text(
            "Filter Leads",
            style: styleElements!
                .subtitle1ThemeScalable(context)
                .copyWith(fontWeight: FontWeight.bold),
          ),
        ),
        Flexible(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: ListView(shrinkWrap: true, children: [
              ListTile(
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/create-meeting.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Show only my leads",
                    style: styleElements!.subtitle1ThemeScalable(context)),
                trailing: Checkbox(
                  value: listType.toLowerCase() ==
                      TicketListType.MY.type.toLowerCase(),
                  onChanged: (bool? value) {
                    listType =
                        value! ? TicketListType.MY.type : TicketListType.ALL.type;
                    widget.callback(status, listType);
                    setState(() {});
                  },
                ),
              ),
              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.ASSIGNED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/assigned.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("All leads",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),
              Visibility(
                visible: !(listType.toLowerCase() ==
                    TicketListType.MY.type.toLowerCase()),
                child: ListTile(
                  onTap: () {
                    widget.callback(TicketListStatus.UNASSIGNED.type, listType);
                    Navigator.pop(context);
                  },
                  leading: Image.asset(
                    'packages/lead_management/assets/appimages/unassigned.png',
                    width: 30,
                    height: 30,
                  ),
                  title: Text("Unassigned",
                      style: styleElements!.subtitle1ThemeScalable(context)),
                ),
              ),
              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.ONHOLD.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/on-hold.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("New",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),
              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.RESOLVED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/resolved.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Open",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),
              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.CLOSED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/closed.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Closed",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),
              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.CLOSED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/closed.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Qualified",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),

              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.CLOSED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/closed.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Unqualified",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),

              ListTile(
                onTap: () {
                  widget.callback(TicketListStatus.CLOSED.type, listType);
                  Navigator.pop(context);
                },
                leading: Image.asset(
                  'packages/lead_management/assets/appimages/closed.png',
                  width: 30,
                  height: 30,
                ),
                title: Text("Completed",
                    style: styleElements!.subtitle1ThemeScalable(context)),
              ),
            ]),
          ),
        ),
      ]),
    );
  }
}
