import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';

import 'package:intl/intl.dart';

import 'package:shared_preferences/shared_preferences.dart';


import '../common_widgets/app_chat_footer.dart';
import '../common_widgets/helpdesk_appbar.dart';
import '../common_widgets/manage_leads_screen.dart';
import '../common_widgets/update_status.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/localization.dart';
import '../utils/text_styling.dart';

class HelpDeskChatScreen extends StatefulWidget {
  final Null Function()? callBack;
  final String? userStatus;
  final Null Function()? callBackNew;
  final Null Function()? refreshList;
  final Null Function()? homePageUnreadCount;
  final bool? isHeaderVisible;
  final String? type;
  final String? personId;
  final bool? isVisible;
  final int? ticketMainId;
  final bool? removeStack;

  @override
  HelpDeskChatScreenState createState() => HelpDeskChatScreenState(
        callBack: callBack,
        userStatus: userStatus,
        callBackNew: callBackNew,
        refreshList: refreshList,
        ticketMainId: ticketMainId,
        homePageUnreadCount: homePageUnreadCount,
        type: type,
        personId: personId,
      );

  HelpDeskChatScreen(
      {required Key? key,
      this.removeStack = false,
      this.personId,
      this.type,
      this.ticketMainId,
      this.callBack,
      this.refreshList,
      this.callBackNew,
      this.userStatus,
      this.homePageUnreadCount,
      this.isVisible,
      this.isHeaderVisible = true})
      : super(key: key);
}

class HelpDeskChatScreenState extends State<HelpDeskChatScreen>
    with WidgetsBindingObserver {
  Null Function()? callBack;

  int? userId = 0;
  String? personId;
  String? type;
  int? allRoomsId;
  int? eventId;
  BuildContext? ctx;
  Null Function()? refreshList;

  String? todayDate;
  Null Function()? callBackNew;
  bool? isNewConversation = false;
  String? userName;
  bool? isRequestApiCalled = false;
  int? callNumber = 0;
  bool? isUserOnCurrentPage = true;

  String? conversationWithId;
  String conversationWithType = "person";
  int? ticketMainId;
  String? mcId;

  SharedPreferences? prefs;
  String? status = "";
  String? userStatus;
  bool? isOnline = false;
  bool? isLoading = false;

  Null Function()? homePageUnreadCount;
  String? myConversationId;
  bool? isGroupConversation = false;
  bool? isRoomAvailable = false;
  String? imageUrl = "";

  String? conversationWithName = "";
  int? pageNumber = 1;
  bool? isAlreadySent = false;
  bool? isReply = false;
  bool? isSearch = false;
  String? date = "";
  String? linkPreview;
  GlobalKey<appChatFooterState>? chatFooterKey = GlobalKey();
  final commentController = TextEditingController();

  bool? isVisible;
  Iterable<RegExpMatch>? matches;
  File? pickedFile;
  String? conversationOwnerId;
  String? conversationOwnerType;
  String? outPutLan;

  File? outputFile;

  HelpDeskChatScreenState({
    this.callBack,
    this.userStatus,
    this.ticketMainId,
    this.callBackNew,
    this.refreshList,
    this.homePageUnreadCount,
    this.type,
    this.personId,
  });

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    switch (state) {
      case AppLifecycleState.resumed:
        print("Resumed--------------------------");

        break;
      case AppLifecycleState.inactive:
        print("inactive--------------------------");
        // widget is inactive
        break;
      case AppLifecycleState.paused:
        print("paused--------------------------");
        // widget is paused
        break;
      case AppLifecycleState.detached:
        print("detached--------------------------");
        // widget is detached
        break;
    }
  }

  @override
  void initState() {
    status = userStatus;
    isUserOnCurrentPage = true;
    isVisible = widget.isVisible;
    RoomAvailableUpdate();

    WidgetsBinding.instance!.addObserver(this);
    WidgetsBinding.instance!.addPostFrameCallback((_) => setPref());
    todayDate = DateFormat('yyyy-MM-dd').format(DateTime.now());
    super.initState();
    updateReadStatus();
  }

  void RoomAvailableUpdate() {
    if (!isRoomAvailable!) {
      isRoomAvailable = true;
    }
  }

  @override
  void dispose() {
    WidgetsBinding.instance!.removeObserver(this);

    super.dispose();
  }

  void updateReadStatus() {}

  Future<void> setPref() async {}
 late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    ctx = this.context;
    return WillPopScope(
        // ignore: missing_return
        onWillPop: () async {
          return true;
        },
        child: SafeArea(
          child: Scaffold(
              backgroundColor: HexColor(AppColors.chatBackGround),
              appBar: widget.isHeaderVisible!
                  ? HelpDeskAppBar(
                      isPicked: true,
                      ticketId: 1283679,
                      issueType: "-",
                      dueDays: "Due in 12 Hrs",
                      priority: "High",
                      ticketStatus: "Unassigned",
                      isNotificationVisible: false,
                      roomId: 197893,
                      roomName: "Savil Mehra",
                      currentStatusName: "New",
                      priorityColor: AppColors.appNotificationColor,
                      showCallbuttons: !isGroupConversation!,
                      agentName: "Desi",
                      agentAvatar: "",
                      agentId: 12344,
                      onMoreClick: () {
                        FocusScopeNode currentFocus = FocusScope.of(context);
                        if (!currentFocus.hasPrimaryFocus) {
                          currentFocus.unfocus();
                        }
                      },
                      onVideoCallback: () {},
                      onCallCallback: () {},
                      priorityCallBack: () {_manageLeads();},
                      statusCallBack: () {_showUpdateStatusSheet();},
                      callBack: () {
                        if (isSearch! && this.mounted) {
                          setState(() {});
                        } else {
                          if (this.mounted)
                            setState(() {
                              isUserOnCurrentPage = false;
                            });

                          Navigator.of(context).pop();
                          if (homePageUnreadCount != null)
                            homePageUnreadCount!();
                        }
                      },
                      isSearch: isSearch,
                      onSearch: (String value) {},
                      onItemSelect: (String value) {},
                      imageUrl: "",
                      title: "Savil",
                      status: "Active",
                      isGroupConversation: isGroupConversation,
                      userType: 'person',
                      userId: 0,
                      notificationCount: 0,
                      agentListCallback: () {},
                    )
                  : null,
              body: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Expanded(
                    child: Container(),
                  ),

                  Align(
                    alignment: Alignment.bottomCenter,
                    child:  appChatFooter(
                      chatFooterKey!,

                      hintText:"Mr. ",
                      linkPreviewUrl: linkPreview,
                      isEmptyTextAccepted: false,
                      audioEvent: (bool isRecorde) {
             
                      },
                      userName: conversationWithName,
                      onCrossCLicked: () {
                    
                      },

                      isShowAddIcon: true,
                      onTyping: (String v) async {

                      },
                      onValueRecieved: (value) async {

                          /*    ToastBuilder().showToast(

                              LeadsLocalizations.of(context)
                                  .translate("something_wrong_debug"),
                              context,
                              HexColor(AppColors.information));*/

                      },
                      onReceiveOption: (value, text) async {

                      },
                    ),
                  )
                ],
              )),
        ));
  }

  void _showUpdateStatusSheet() {
    showModalBottomSheet(
      context: ctx!,
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      builder: (BuildContext context) {
        return UpdateStatusSheet(

          doneCallback: (value) {

          },
        );
      },
    );
  }

  void _manageLeads() {
    showModalBottomSheet(
      context: ctx!,
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      builder: (BuildContext context) {
        return ManageLeadsSheet(

          doneCallback: (value) {

          },
        );
      },
    );
  }
}
