import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/app_buttons.dart';
import 'package:lead_management/presentation/utils/colors.dart';
import 'package:lead_management/presentation/utils/custom_app_bar.dart';
import 'package:lead_management/presentation/utils/customcard.dart';
import 'package:lead_management/presentation/utils/hexColors.dart';
import 'package:lead_management/presentation/utils/text_styling.dart';

import '../../enums/ticket_list_type.dart';
import '../common_widgets/app_find_card.dart';
import '../common_widgets/customgridDelegate.dart';
import '../utils/localization.dart';
import 'leade_status_page.dart';
import 'manage_incentive.dart';

class LeadsSettingsPage extends StatefulWidget {
  @override
  LeadsSettingsPageState createState() => LeadsSettingsPageState();
}

class LeadsSettingsPageState extends State<LeadsSettingsPage> {
  String? date;

  int startTime = DateTime(1900).millisecondsSinceEpoch;
  int endTime = DateTime.now().millisecondsSinceEpoch;
  TextStyleElements? styleElements;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {});
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(
          context,
          appBarTitle: "Lead Management",
          onBackButtonPress: () {
            Navigator.pop(context);
          },
        ),
        body: ListView(
          children: [
            InkWell(
              onTap: () {

                Navigator.push(context,
                    MaterialPageRoute(builder: (BuildContext context) {
                      return ManageLeadStatusPage();
                    }));

              },
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset(
                        'packages/lead_management/assets/appimages/business-admin.png',
                        width: 36,
                        height: 36,
                      ),
                      title: Text(
                        LeadsLocalizations.of(context) != null
                            ? LeadsLocalizations.of(context)!
                                .translate("leads_s")
                            : "",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        LeadsLocalizations.of(context) != null
                            ? LeadsLocalizations.of(context)!
                                .translate("leads_s_des")
                            : "",
                        style: styleElements!.captionThemeScalable(context),
                      ),
                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.keyboard_arrow_right),
                      ),
                    ),
                  )),
            ),
            InkWell(
              onTap: () {

                Navigator.push(context,
                    MaterialPageRoute(builder: (BuildContext context) {
                      return ManageIncentivePage();
                    }));

              },
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: Image.asset(
                        'packages/lead_management/assets/appimages/business-settings.png',
                        width: 36,
                        height: 36,
                      ),
                      title: Text(
                        LeadsLocalizations.of(context) != null
                            ? LeadsLocalizations.of(context)!
                                .translate("lead_incent")
                            : "",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),
                      subtitle: Text(
                        LeadsLocalizations.of(context) != null
                            ? LeadsLocalizations.of(context)!
                                .translate("lead_incent_d")
                            : "",
                        style: styleElements!.captionThemeScalable(context),
                      ),
                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.keyboard_arrow_right),
                      ),
                    ),
                  )),
            ),
          ],
        ),
      ),
    );
  }

  void openTicketListPage(BuildContext context,
      {String? status,
      String? listType,
      bool isNewTicket = false,
      bool showOptions = true,
      bool showRating = false}) {
    /*  Navigator.push(context, MaterialPageRoute(builder: (BuildContext context) {
      return HelpDeskTicketListPage(
          isNewTicket: isNewTicket,
          status: status,
          listType: listType,
          showOptions: showOptions,
          showRating: showRating,
          callback: () {
            refresh();
          });
    }));*/
  }

  void refresh() {
    // fetchData(startTime, endTime);
  }
}

class LeadsSettingsPageDisplayWidget extends StatelessWidget {
  final String? title;
  final String? subtitle;
  final bool isIconShow;
  final Function? onPressed;
  final Widget? icon;

  LeadsSettingsPageDisplayWidget(
      {this.title,
      this.subtitle,
      this.isIconShow = false,
      this.onPressed,
      this.icon});

  @override
  Widget build(BuildContext context) {
    var styleElements = TextStyleElements(context);
    return appListCard(
      onTap: onPressed,
      padding: EdgeInsets.only(left: 8, bottom: 6, right: 8, top: 8),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Visibility(visible: isIconShow, child: icon ?? Container()),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  title ?? "",
                  style: isIconShow
                      ? styleElements.subtitle1ThemeScalable(context).copyWith(
                            fontWeight: FontWeight.bold,
                          )
                      : styleElements.bodyText2ThemeScalable(context),
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                ),
                isIconShow ? Container() : Spacer(),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    if (!isIconShow) Spacer(),
                    if (isIconShow)
                      Flexible(
                        child: Text(
                          subtitle ?? "",
                          style: styleElements.bodyText2ThemeScalable(context),
                        ),
                      ),
                    if (!isIconShow)
                      Text(
                        subtitle ?? "",
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                  ],
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
